<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="68px"
      @submit.native.prevent
    >
      <el-form-item label="评估项目" prop="item">
        <el-input
          v-model="queryParams.item"
          placeholder="请输入名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:harbor:add']"
          >新增</el-button
        >
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="dsTaskList">
      <el-table-column label="序号" align="center" type="index" />
      <el-table-column label="方案类型" align="center" prop="plan" />
      <el-table-column label="类型" align="center" prop="type" />
      <el-table-column label="评估项目" align="center" prop="item" />
      <el-table-column label="计算方法" align="center" prop="itemDetail" />
      <el-table-column label="单位" align="center" prop="unit" />
      <el-table-column label="要素指标" align="center" prop="code" />
      <el-table-column label="归一化" align="center" prop="normal" />
      <el-table-column label="要素权重" align="center" prop="weight" />
      <el-table-column label="分类指标" align="center" prop="classifyIndex" />
      <el-table-column label="分类权重" align="center" prop="classifyWeight" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:harbor:edit']"
            >修改</el-button
          >
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:harbor:remove']"
            >删除</el-button
          >
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改港口信息对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="750px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="100px">
        <el-row>
          <el-col :span="12">
            <el-form-item label="方案类型" prop="plan">
              <el-input v-model="form.plan" placeholder="请输入方案类型" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="类型" prop="type">
              <el-select v-model="form.type" placeholder="请选择">
                <el-option
                  v-for="column in deptOptions"
                  :key="column.value"
                  :label="column.label"
                  :value="column.value"
                ></el-option>
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="12">
            <el-form-item label="评估项目" prop="item">
              <el-input v-model="form.item" placeholder="请输入评估项目" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="计算方法" prop="itemDetail">
              <el-input v-model="form.itemDetail" placeholder="请输入" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="单位" prop="unit">
              <el-input v-model="form.unit" placeholder="请输入单位" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="要素指标" prop="code">
              <el-input v-model="form.code" placeholder="请输入要素指标" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="归一化" prop="normal">
              <el-input v-model="form.normal" placeholder="请输入归一化" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="要素权重" prop="weight">
              <el-input v-model="form.weight" placeholder="请输入要素权重" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="分类指标" prop="classifyIndex">
              <el-input v-model="form.classifyIndex" placeholder="请输入分类指标" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="分类权重" prop="classifyWeight">
              <el-input v-model="form.classifyWeight" placeholder="请输入分类权重" />
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  addAssessItem,
  delAssessItem,
  updateAssessItem,
  getAssessList,
  getAssessItem,
} from "@/api/manage/assess";
import Treeselect from "@riophae/vue-treeselect";
import "@riophae/vue-treeselect/dist/vue-treeselect.css";

export default {
  name: "Harbor",
  components: { Treeselect },
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      selectShipType: "",
      // 部门树选项
      deptOptions: [
        {
          label: "基地",
          value: "JD",
        },
        {
          label: "支队",
          value: "ZD",
        },
      ],
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 保障需求表格数据
      dsTaskList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        plan: [{ required: true, message: "该字段不能为空", trigger: "blur" }],
        type: [{ required: true, message: "该字段不能为空", trigger: "blur" }],
        item: [{ required: true, message: "该字段不能为空", trigger: "blur" }],
        itemDetail: [{ required: true, message: "该字段不能为空", trigger: "blur" }],
        unit: [{ required: true, message: "该字段不能为空", trigger: "blur" }],
        code: [{ required: true, message: "该字段不能为空", trigger: "blur" }],
        normal: [{ required: true, message: "该字段不能为空", trigger: "blur" }],
        weight: [{ required: true, message: "该字段不能为空", trigger: "blur" }],
        classifyIndex: [{ required: true, message: "该字段不能为空", trigger: "blur" }],
        classifyWeight: [{ required: true, message: "该字段不能为空", trigger: "blur" }],
      },
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    /** 查询table列表 */
    getList() {
      this.loading = true;
      getAssessList(this.queryParams).then((response) => {
        this.dsTaskList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加待补给舰艇";
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      this.$modal
        .confirm('是否确认删除"' + row.item + '"的数据项？')
        .then(function () {
          return delAssessItem(row.pkid);
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      getAssessItem(row.pkid).then((response) => {
        this.form = response.data;
        this.open = true;
        this.title = "修改信息";
      });
    },

    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        type: "",
        plan: "",
        item: "",
        itemDetail: "",
        unit: "",
        code: "",
        normal: "",
        weight: null,
        classifyIndex: "",
        classifyWeight: null,
      };
      this.resetForm("form");
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          console.log(this.form);

          if (this.form.pkid != null) {
            updateAssessItem(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addAssessItem(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
  },
};
</script>
